@@ -64,17 +64,23 @@ typedef struct tag_s {
   struct tag_s *next;
 } tag_t;
 
-typedef struct node_s {
+typedef struct {
   item_id_t id;
   item_id_t version;
+  user_t *user;
+  time_t time;
+  gboolean visible;
+  int flags;
+  tag_t *tag;
+  
+} base_object_t;
+
+typedef struct node_s {
+  base_object_t base;
+
   pos_t pos;
   lpos_t lpos;
-  user_t *user;
-  gboolean visible;
-  time_t time;
-  tag_t *tag;
   int ways;
-  int flags;
   float zoom_max;
 
   /* icon */
@@ -86,6 +92,16 @@ typedef struct node_s {
   struct node_s *next;
 } node_t;
 
+typedef enum {
+  ILLEGAL=0, NODE, WAY, RELATION, NODE_ID, WAY_ID, RELATION_ID
+} type_t;
+
+typedef struct item_id_chain_s {
+  type_t type;
+  item_id_t id;
+  struct item_id_chain_s *next;
+} item_id_chain_t;
+
 typedef struct node_chain {
   node_t *node;
   struct node_chain *next;
@@ -95,15 +111,9 @@ typedef struct node_chain {
 #define OSM_DRAW_FLAG_BG    (1<<1)
 
 typedef struct way_s {
-  item_id_t id;
-  item_id_t version;
-  item_id_t changeset;
-  user_t *user;
-  gboolean visible;
-  time_t time;
-  tag_t *tag;
+  base_object_t base;
+
   node_chain_t *node_chain;
-  int flags;
 
   /* visual representation from elemstyle */
   struct {
@@ -137,17 +147,30 @@ typedef struct way_chain {
   struct way_chain *next;
 } way_chain_t;
 
-typedef struct relation_s {
-  item_id_t id;
-  item_id_t version;
-  item_id_t changeset;
-  user_t *user;
-  gboolean visible;
-  time_t time;
-  tag_t *tag;
-  struct member_s *member;
-  int flags;
+/* return a pointer to the "base" object of an object */
+#define OBJECT_BASE(a)     ((base_object_t*)((a).ptr))
+#define OBJECT_ID(a)       (OBJECT_BASE(a)->id)
+#define OBJECT_VERSION(a)  (OBJECT_BASE(a)->version)
+#define OBJECT_USER(a)     (OBJECT_BASE(a)->user)
+#define OBJECT_TIME(a)     (OBJECT_BASE(a)->time)
+#define OBJECT_TAG(a)      (OBJECT_BASE(a)->tag)
+#define OBJECT_VISIBLE(a)  (OBJECT_BASE(a)->visible)
+#define OBJECT_FLAGS(a)    (OBJECT_BASE(a)->flags)
 
+/* osm base type access macros */
+#define OSM_BASE(a)        ((base_object_t*)(a))
+#define OSM_ID(a)          (OSM_BASE(a)->id)
+#define OSM_VERSION(a)     (OSM_BASE(a)->version)
+#define OSM_USER(a)        (OSM_BASE(a)->user)
+#define OSM_TIME(a)        (OSM_BASE(a)->time)
+#define OSM_TAG(a)         (OSM_BASE(a)->tag)
+#define OSM_VISIBLE(a)     (OSM_BASE(a)->visible)
+#define OSM_FLAGS(a)       (OSM_BASE(a)->flags)
+
+typedef struct relation_s {
+  base_object_t base;
+
+  struct member_s *member;
   struct relation_s *next;
 } relation_t;
 
@@ -177,10 +200,6 @@ typedef struct {
   hash_item_t *hash[65536];
 } hash_table_t;
 
-typedef enum {
-  ILLEGAL=0, NODE, WAY, RELATION, NODE_ID, WAY_ID, RELATION_ID
-} type_t;
-
 typedef struct {
   type_t type;
   union {
@@ -229,7 +248,7 @@ gboolean osm_node_has_tag(node_t *node);
 
 void osm_node_dump(node_t *node);
 
-void osm_way_free(way_t *way);
+void osm_way_free(hash_table_t *hash_table, way_t *way);
 void osm_way_dump(way_t *way);
 char *osm_way_get_value(way_t *way, char *key);
 gboolean osm_node_has_value(node_t *node, char *str);
@@ -237,10 +256,11 @@ gboolean osm_way_has_value(way_t *way, char *str);
 void osm_way_append_node(way_t *way, node_t *node);
 
 gboolean osm_node_in_way(way_t *way, node_t *node);
+gboolean osm_node_in_other_way(osm_t *osm, way_t *way, node_t *node);
 
 void osm_node_chain_free(node_chain_t *node_chain);
 int osm_node_chain_length(node_chain_t *node_chain);
-void osm_node_free(struct icon_s **icon, node_t *node);
+void osm_node_free(hash_table_t *hash, struct icon_s **icon, node_t *node);
 
 void osm_members_free(member_t *member);
 void osm_member_free(member_t *member);
@@ -263,8 +283,9 @@ way_t *osm_get_way_by_id(osm_t *osm, item_id_t id);
 relation_t *osm_get_relation_by_id(osm_t *osm, item_id_t id);
 
 guint osm_way_number_of_nodes(way_t *way);
-relation_chain_t *osm_node_to_relation(osm_t *osm, node_t *node);
-relation_chain_t *osm_way_to_relation(osm_t *osm, way_t *way);
+relation_chain_t *osm_node_to_relation(osm_t *osm, node_t *node, 
+				       gboolean via_way);
+relation_chain_t *osm_way_to_relation(osm_t *osm, way_t *way); 
 relation_chain_t *osm_relation_to_relation(osm_t *osm, relation_t *relation);
 relation_chain_t *osm_object_to_relation(osm_t *osm, object_t *object);
 void osm_relation_chain_free(relation_chain_t *relation_chain);
@@ -277,7 +298,8 @@ void osm_node_restore(osm_t *osm, node_t *node);
 way_chain_t *osm_node_delete(osm_t *osm, struct icon_s **icon, node_t *node, 
 			     gboolean permanently, gboolean affect_ways);
 void osm_way_delete(osm_t *osm, struct icon_s **icon, way_t *way, 
-		    gboolean permanently);
+		    gboolean perm);
+void osm_way_restore(osm_t *osm, way_t *way, item_id_chain_t *id_chain);
 
 way_t *osm_way_new(void);
 void osm_way_attach(osm_t *osm, way_t *way);
@@ -297,7 +319,7 @@ node_t *osm_way_get_last_node(way_t *way);
 node_t *osm_way_get_first_node(way_t *way);
 void osm_way_rotate(way_t *way, gint offset);
 
-tag_t *osm_tags_copy(tag_t *tag, gboolean update_creator);
+tag_t *osm_tags_copy(tag_t *tag);
 
 relation_t *osm_relation_new(void);
 void osm_relation_free(relation_t *relation);
@@ -306,13 +328,15 @@ void osm_relation_delete(osm_t *osm, relation_t *relation,
 			 gboolean permanently);
 gint osm_relation_members_num(relation_t *relation);
 
+gboolean osm_object_is_real(object_t *object);
 char *osm_object_type_string(object_t *object);
 char *osm_object_id_string(object_t *object);
 char *osm_object_string(object_t *object);
 tag_t *osm_object_get_tags(object_t *object);
+item_id_t osm_object_get_id(object_t *object);
 void osm_object_set_flags(object_t *map_item, int set, int clr);
 char *osm_object_get_name(object_t *object);
-char *osm_object_get_speaking_name(object_t *object);
+gboolean osm_object_is_same(object_t *obj1, object_t *obj2);
 
 #endif /* OSM_H */
 
